# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/chaostoolkit/chaosplatform-experiment/compare/0.1.0...HEAD

## [0.1.1][] - 2018-10-01

[0.1.1]: https://github.com/chaostoolkit/chaosplatform-experiment/compare/0.1.0...0.1.0

### Changed

-   Set minimal Python version to 3.6

## [0.1.0][] - 2018-10-01

[0.1.0]: https://github.com/chaostoolkit/chaosplatform-experiment/tree/0.1.0

### Added

-   Initial release